import axios from 'axios';
import { AsyncStorage } from 'react-native';
import address from './constants/connection';

// Insira seu IP e rode o backend localmente
const api = axios.create({
  baseURL: `http://${address.ip}:3000/api`,
});

export default api;

export async function isLoggedIn() {
  const userId = parseInt((await AsyncStorage.getItem('userId')) ?? -1);
  return userId !== -1;
}

export const registerAppoio = async data => {
  const userId = parseInt((await AsyncStorage.getItem('userId')) ?? -1);

  const formData = new FormData();

  formData.append('userId', userId);
  formData.append('appoioName', data.name);
  formData.append('category', data.category);
  if (data.appId) {
    formData.append('appId', data.appId);
  }

  formData.append('appVersion', data.appVersion);
  formData.append('operatingSystem', data.os);
  formData.append('operatingSystemVersion', data.osVersion);
  formData.append('tags', JSON.stringify(data.tags));

  data.steps.forEach(step => {
    formData.append('images', step.imgURL);
    delete step.imgURL;
  });

  formData.append('steps', JSON.stringify(data.steps));

  try {
    await api.post('tutorial/registration', formData);
  } catch (error) {
    throw {
      title: 'Falha ao enviar appoio',
      message: 'Tente novamente em alguns minutos.',
    };
  }
};
export const editAppoio = async data => {
  const formData = new FormData();

  formData.append('tutorialId', data.data.tutorialId);
  formData.append('appoioName', data.data.name);
  formData.append('category', data.data.category);

  if (data.data.appId) {
    formData.append('appId', data.data.appId);
  }
  if (data.data.appVersion) {
    formData.append('appVersion', data.data.appVersion);
  }
  if (data.data.os) {
    formData.append('operatingSystem', data.data.os);
  }
  if (data.data.osVersion) {
    formData.append('operatingSystemVersion', data.data.osVersion);
  }

  formData.append('tags', JSON.stringify(data.data.tags));

  let hasImage = false;
  data.data.steps.forEach(step => {
    formData.append('images', step.imgURL);
    if (step.imgURL) {
      hasImage = true;
    }
    delete step.imgURL;
    if (!hasImage) {
      delete step.order;
    }
  });

  formData.append('steps', JSON.stringify(data.data.steps));

  try {
    const response = await api.put('tutorial/edit', formData);
    console.log(response);
  } catch (error) {
    throw {
      title: 'Falha ao editar appoio',
      message: 'Tente novamente em alguns minutos.',
    };
  }
};

export const updateInstalledApps = async data => {
  const apps = { appIds: data };
  let response;
  try {
    response = await api.patch('/app/installed', apps);
  } catch (error) {
    throw {
      title: 'Falha ao atualizar os Apps instalados',
      message: 'Tente novamente em alguns minutos.',
      erro: error,
    };
  }
  return response;
};
