import React, { useState } from 'react';
import { StyleSheet, Text, View } from 'react-native';
import { CheckBox } from 'react-native-elements';
import colors from '../constants/colors';

/**
 * Tela de modelo com um componente de modelo
 *
 * @author            João Leão, Pablo Alles, Marlon Saldanha
 * @param options     Array de String com as opções de cada botão.
 * @param onChange    Callback que retorna o valor selecionado.
 *
 * @example           <ButtonGroupComponent
 *                      label="Gênero"
 *                      options={['Masculino','Feminino','Outro']}
 *                      onChange={value => console.log(value)}
 *                    />
 */

export default function ButtonGroupComponent({
  options,
  onChange,
  label,
  style,
}) {
  const [selected, setSelected] = useState(0);

  const toggleChecked = value => {
    setSelected(value);
    onChange(value);
  };

  return (
    <View style={style}>
      <Text style={styles.title}>{label}</Text>
      <View style={styles.container}>
        {options.map((option, index) => (
          <CheckBox
            key={index}
            title={option}
            checkedIcon="dot-circle-o"
            uncheckedIcon="circle-o"
            checked={index === selected}
            containerStyle={styles.buttonStyle}
            checkedColor={colors.quaternary}
            uncheckedColor={colors.textDisabled}
            onPress={() => toggleChecked(index)}
          />
        ))}
      </View>
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flexDirection: 'column',
    flexWrap: 'wrap',
  },
  title: {
    fontSize: 18,
    color: colors.textDisabled,
    marginBottom: 5,
  },
  buttonStyle: {
    backgroundColor: 'transparent',
    padding: 0,
    borderWidth: 0,
  },
});
