/**
 * Componente que cria um item de uma lista que contém um título e um botão para abrir o tutorial
 *
 * @author           Eduardo Cardoso
 * @param id         OBRIGATORIO - ID do tutorial
 * @param title      OBRIGATORIO - Titulo do tutorial
 * @param action     OBRIGATORIO - ação do botão do item da lista
 * @example          <ItemListComponent
 *                     title={"Como inverter a câmera do celular?"}
 *                   />
 */

import React from 'react';
import Icon from 'react-native-vector-icons/Feather';
import { StyleSheet, Text, View, TouchableOpacity } from 'react-native';
import colors from '../constants/colors';

export default function ItemListComponent({ id, title, action }) {
  return (
    <TouchableOpacity style={styles.container} onPress={e => action(id)}>
      <Text style={styles.text}>{title}</Text>
      <Icon.Button
        name="arrow-right"
        color={colors.primary}
        backgroundColor={colors.transparent}
      />
    </TouchableOpacity>
  );
}

const styles = StyleSheet.create({
  container: {
    marginTop: 20,
    borderRadius: 10,
    borderWidth: 1,
    borderColor: colors.backgroundDisabled,
    padding: 10,
    width: '100%',
    justifyContent: 'space-between',
    flexDirection: 'row',
    alignItems: 'center',
  },
  text: {
    fontSize: 20,
    width: '90%',
  },
});
