/**
 * Componente de modelo que cria uma barra de buscas
 *
 * @author              Marlon Saldanha, Pablo Alles
 * @param sendSearch    callback chamado quando o conteúdo da search bar é alterado
 * @example             <SearchBarComponent
 *                      />
 */

import React, { useEffect, useState } from 'react';
import { StyleSheet, View, TextInput, AsyncStorage } from 'react-native';
import FeatherIcon from 'react-native-vector-icons/Feather';

export default function SearchBarComponent({ sendSearch, handleClick }) {
  const [value, setValue] = useState('');
  const [placeholderText, setPlaceholderText] = useState(
    'Buscar por tags ou títulos...',
  );

  useEffect(() => {
    async function loadFlag() {
      const isAdmin = JSON.parse(await AsyncStorage.getItem('isAdmin'));
      if (isAdmin) setPlaceholderText('Buscar...');
    }

    loadFlag();
  }, [setPlaceholderText]);

  function handleChange(value2) {
    setValue(value2);
    sendSearch(value2);
  }

  return (
    <View style={styles.bar}>
      <FeatherIcon name="search" size={24} color="white" style={styles.icon} />
      <TextInput
        value={value}
        placeholder={placeholderText}
        placeholderTextColor="white"
        style={styles.input}
        onSubmitEditing={handleClick}
        onChangeText={text => handleChange(text)}
      />
    </View>
  );
}

const styles = StyleSheet.create({
  bar: {
    flexDirection: 'row',
    backgroundColor: 'rgba(255, 255, 255, 0.3)',
    height: 38,
    alignItems: 'center',
    borderRadius: 50,
    paddingLeft: 54,
    position: 'relative',
  },
  input: {
    fontSize: 18,
    color: 'white',
    fontWeight: '500',
    width: '100%',
    paddingRight: 20,
  },
  icon: {
    left: 15,
    position: 'absolute',
  },
});
