/**
 * Componente de Passos de um tutorial
 *
 * @author                      João Leão
 * @param index                 Index do passo
 * @param handleVideo           Função para adquirir o link do video
 * @param handleDescription     Função para adquirir a descrição do passo
 * @param handleImage           Função para adquirir a imagem
 * @example                     <StepComponent
 *                                  text={"teste"}
 *                              />
 */

import React from 'react';
import { View } from 'react-native';
import TextArea from './TextAreaComponent';
import InputText from './InputTextComponent';
import AddImage from './AddImageComponent';

export default function StepComponent({
  index,
  item,
  handleDescription,
  handleVideo,
  handleImage,
  handleDelete,
}) {
  return (
    <View>
      <TextArea
        name={`Passo ${index + 1}`}
        value={item.description}
        trash={handleDelete ? () => handleDelete(item.order) : null}
        sendText={text => handleDescription(text, item.order)}
      />
      <InputText
        placeholder="Link do Vídeo"
        value={item.videoURL}
        onChangeText={text => handleVideo(text, index)}
      />
      <AddImage
        value={item.imgURL}
        onSelectImage={imgObj => handleImage(imgObj || item.imgURL, item.order)}
      />
    </View>
  );
}
