/**
 *
 * Componente de modelo destinado a criação da barra de seleção das categorias do aplicativo
 *
 * @author              Bernardo de Cesaro
 * @param children      Definição de tabs que serão apresentadas para o usuário
 * @example
 *                       <TabSelectionComponent>
 *                         <View title="APLICATIVOS" style={styles.content} />
 *                         <View title="CELULAR" style={styles.content} />
 *                         <View title="CONCEITOS" style={styles.content} />
 *                       </TabSelectionComponent>
 */

import React, { useState } from 'react';
import { StyleSheet, Text, View, TouchableOpacity } from 'react-native';
import colors from '../constants/colors';

export default function TabSelectionComponent({
  children,
  onPress = () => {},
  style,
  tabSelected,
}) {
  const [activeTab, setActiveTab] = useState(tabSelected);

  const handleActiveTab = index => {
    setActiveTab(index);
    onPress(index);
  };

  return (
    <View style={[styles.container, style]}>
      {children.map(({ props: { title } }, index) => (
        <TouchableOpacity
          style={[styles.tab, index === activeTab ? styles.tabActive : []]}
          onPress={() => handleActiveTab(index)}
          key={index}
        >
          <Text
            style={[styles.text, index === activeTab ? styles.textActive : []]}
          >
            {title}
          </Text>
        </TouchableOpacity>
      ))}
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    backgroundColor: colors.backgroundItem,
    borderRadius: 25,
  },
  tab: {
    flex: 1,
    paddingVertical: 15,
    justifyContent: 'center',
  },
  tabActive: {
    borderRadius: 25,
    backgroundColor: colors.primary,
  },
  text: {
    color: colors.text,
    fontWeight: 'bold',
    textAlign: 'center',
  },
  textActive: {
    color: colors.textWhite,
  },
});
