/**
 * Tela de modelo com um componente de modelo
 *
 * @author            Arthur Henz, Eduardo Cardoso, Enzo Russo e João Severo
 * @example           <ExportUserDataScreen/>
 */

import React, { useState, useEffect } from 'react';
import {
  StyleSheet,
  View,
  Text,
  Alert,
  Image,
  AsyncStorage,
} from 'react-native';
import colors from '../constants/colors';
import api from '../api';
import HeaderComponent from '../components/HeaderComponent';
import BodyComponent from '../components/BodyComponent';
import InputTextComponent from '../components/InputTextComponent';
import ButtonComponent from '../components/ButtonComponent';

export default function ExportUserDataScreen() {
  const [email, setEmail] = useState(''); // TODO pegar do async storage do usuário

  useEffect(() => {
    async function getUserEmail() {
      await AsyncStorage.getItem('email').then(value => setEmail(value));
    }
    getUserEmail();
  }, []);

  function isValidData() {
    if (!email.length) return false;
    return true;
  }

  async function handleExport() {
    const response = await api.post('user/export', { email });
    if (response.data.status === 500) {
      Alert.alert(
        'Falha ao exportar arquivo',
        'Houve um problema ao tentar exportar. Tente novamente mais tarde.',
      );
    } else {
      Alert.alert('Exportado!', 'Verifique sua caixa de entrada.', [
        { text: 'OK' },
      ]);
    }
  }

  return (
    <View style={styles.screen}>
      <HeaderComponent large>
        <Image
          style={{ alignSelf: 'center', width: 90, height: 46 }}
          source={require('../../assets/logo-p.png')}
        />
      </HeaderComponent>

      <BodyComponent
        buttonAction={handleExport}
        buttonDisabled={!isValidData()}
        buttonText="Enviar"
        buttonBackgroundColor={colors.primary}
        buttonTextColor={colors.textWhite}
      >
        <Text style={styles.description}>
          Informe o e-mail abaixo para qual{'\n'}deveremos enviar o relatório:
        </Text>
        <View style={styles.textBox}>
          <Text style={styles.emailText}>E-mail</Text>
          <InputTextComponent
            value={email}
            emailType
            onChangeText={email => setEmail(email)}
          />
        </View>
      </BodyComponent>
    </View>
  );
}
const styles = StyleSheet.create({
  screen: {
    flex: 1,
    backgroundColor: colors.primary,
    alignItems: 'center',
  },

  emailText: {
    color: colors.primary,
    fontSize: 20,
  },
  header: {
    alignItems: 'center',
    justifyContent: 'center',
    color: colors.textWhite,
    fontSize: 30,
    fontWeight: 'bold',
  },
  description: {
    color: colors.text,
    fontSize: 22,
    textAlign: 'center',
    paddingTop: '10%',
  },
});
